<?php if (!defined('ABSPATH') || !is_admin()) exit; // Exit if accessed directly or not admin interface

// Don't return the form if user doesn't have the capabilities
if(!current_user_can("publish_pages")):
    echo '<p class="message message-error">' . __('You don\'t have permission to create pages','rp-spintax-post-creator') . '</p>';        
else: // allowed user capabilities
    $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'post';
    $status = isset($_POST['status']) ? sanitize_text_field($_POST['status']) : 'draft';
    $change_kw = isset($_POST['change_kw']) ? sanitize_text_field($_POST['change_kw']): '';
    $titles = isset($_POST['spintax_title']) ? sanitize_textarea_field($_POST['spintax_title']) : '';
    $spintax = isset($_POST['spintax_text']) ? wp_kses_post($_POST['spintax_text']) : '';
    $keywords = isset($_POST['keywords']) ? sanitize_textarea_field($_POST['keywords']) : '';
?>

    <div class="wrap rp-spintax-post-creator-wrap">
    <h1><?php echo __('Create Posts or Pages','rp-spintax-post-creator');?></h1>
    <div class="content">

    <?php
    if( // Check if all the fields are completed
        !empty($type) && 
        !empty($status) && 
        !empty($change_kw) &&
        !empty($titles) && 
        !empty($spintax) && 
        !empty($keywords) 
        ){

        $wk = new RP_Spintax_Post_Creator_Worker($type, $status, $change_kw, $titles, $spintax, $keywords);
        $count = $wk->init();
        
        if($type == "post")
            echo '<p class="message">' . sprintf(__('%s posts created','rp-spintax-post-creator'), intval($count)) . '</p>';
        else
            echo '<p class="message">' . sprintf(__('%s pages created','rp-spintax-post-creator'), intval($count)) . '</p>';
    } else {
        if ($_SERVER['REQUEST_METHOD'] == "POST")  //Return message if empty field on Submit
            echo '<p class="message message-error">' . __('Please complete all the fields','rp-spintax-post-creator') . '</p>';
    }
    ?>

    <form method="post">
    <table class="form-table">
    <tr>
        <th scope="row">
            <label for="type"><?php echo __('Publish as Page or Post?','rp-spintax-post-creator');?></label>
        </th>
        <td>
            <input type="radio" name="type" value="post" <?php checked(esc_attr($type), "post");?>/><span><?php echo __('Post','rp-spintax-post-creator');?></span>
            <input type="radio" name="type" value="page" <?php checked(esc_attr($type), "page");?>/><span><?php echo __('Page','rp-spintax-post-creator');?></span>
        </td>
    </tr>
    <tr>
        <th scope="row">
            <label for="status"><?php echo __('Publish or Draft','rp-spintax-post-creator');?></label>
        </th>
        <td>
            <input type="radio" name="status" value="publish" <?php checked(esc_attr($status), "publish");?>/><span><?php echo __('Publish','rp-spintax-post-creator');?></span>
            <input type="radio" name="status" value="draft" <?php checked(esc_attr($status), "draft");?>/><span><?php echo __('Draft','rp-spintax-post-creator');?></span>
        </td>
    </tr>
    <tr>
        <th scope="row">
            <label for="change_kw"><?php echo __('Word to replace with Keyword','rp-spintax-post-creator');?></label>
        </th>
        <td>
            <input type="text" name="change_kw" id="change_kw" value="<?php echo esc_attr($change_kw);?>" placeholder="<?php echo __('To Replace','rp-spintax-post-creator');?>"/>
        </td>
    </tr>
    <tr>
        <th scope="row">
        <label for="spintax_title"><?php echo __('Spintax for Title','rp-spintax-post-creator');?></label>
        </th>
        <td>
        <textarea class="large-text" name="spintax_title" id="spintax_title" rows="5" placeholder="<?php echo __('Spintax for Title','rp-spintax-post-creator');?>"><?php echo esc_textarea($titles);?></textarea>
        </td>
    </tr>
    <tr>
        <th scope="row">
        <label for="spintax_text"><?php echo __('Spintax for Text','rp-spintax-post-creator');?></label>
        </th>
        <td>
        <textarea class="large-text" name="spintax_text" id="spintax_text" rows="5" placeholder="<?php echo __('Spintax for Text','rp-spintax-post-creator');?>"><?php echo esc_textarea($spintax);?></textarea>
        </td>
    </tr>
    <tr>
        <th scope="row">
        <label for="keywords"><?php echo __('Keyword (One each line)','rp-spintax-post-creator');?></label>
        </th>
        <td>
        <textarea class="large-text" name="keywords" id="keywords" rows="5" placeholder="<?php echo __('Keywords','rp-spintax-post-creator');?>"><?php echo esc_textarea($keywords);?></textarea>
        </td>
    </tr>
    <tr>
        <td>
        <input type="submit" value="<?php echo __('Generate content','rp-spintax-post-creator');?>"/>
        </td>
        <td>
        <span id="off_btn"><?php echo __('Fill with TEST content','rp-spintax-post-creator');?></span>
        </td>
    </tr>
    </table>
    </form>

    </div><!-- End content -->
    </div><!-- End wrap -->
    <?php include_once plugin_dir_path(__FILE__) . 'rp_footer.php';

endif; // End allowed user capabilities ?>